==> ktp-accounts-kcm-21.04.0.tar.xz: ktp-accounts-kcm-21.04.0/plugins/pintxo/ktpaccountskcm_plugin_pintxo.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Pintxo connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Pinxto menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Pintxo.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Pintxo.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Pintxo.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Pintxo.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Pintxo-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Pintxo.
Comment[en_GB]=Custom account configuration user interface for accounts using the Pintxo connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Pintxo.
Comment[et]=Pintxo ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «Pintxo» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Pintxo-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur de configuration de comptes pour les comptes employant le gestionnaire de connexion « Pintxo ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Pintxo.
Comment[hu]=Egyedi beállítófelület a Pintxo kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Pintxo
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Pintxo.
Comment[kk]=Pintxo байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[ko]=Pintxo 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Pintxo ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Pintxo tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Pintxo“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Pintxo verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med Pintxo tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Pintxo.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Pintxo.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Pintxo.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Pintxo.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Pintxo.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Pintxo.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Pintxo.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Пинтхо.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Пинтхо.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Pintxo.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Pintxo.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Pintxo.
Comment[tr]=Pintxo bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікових записів, для роботи яких використовуються засоби керування з’єднанням Pintxo.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Pintxo connection manager.xx
Comment[zh_CN]=通过 Pintxo 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Pintxo 連線管理員的帳號自訂帳號設定使用者介面。
Icon=phone
Name=Pintxo Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Pinxto
Name[ca]=Interfície d'usuari de configuració del compte de Pintxo
Name[ca@valencia]=Interfície d'usuari de configuració del compte de Pintxo
Name[cs]=Uživatelské rozhraní nastavení účtu Pintxo
Name[da]=Brugerflade til Pintxo kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Pintxo-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη Pintxo
Name[en_GB]=Pintxo Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Pintxo
Name[et]=Pintxo konto seadistamise kasutajaliides
Name[eu]=«Pintxo» kontuak konfiguratzeko erabiltzaile interfazea
Name[fi]=Pintxo-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Pintxo ».
Name[gl]=Interface de usuario para a configuración de contas de Pintxo
Name[hu]=Pintxo azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Pintxo
Name[it]=Interfaccia utente di configurazione account Pintxo
Name[kk]=Pintxo тіркелгі пайдаланушы интерфейсін баптау
Name[ko]=Pintxo 계정 설정 사용자 인터페이스
Name[lt]=Pintxo paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Pintxo-konto
Name[nds]=Pintxo-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Pintxo accountconfiguratie
Name[nn]=Brukarflate for å setja opp Pintxo-konto
Name[pl]=Nakładka graficzna do ustawiania konta Pintxo
Name[pt]=Interface de Configuração de Contas do Pintxo
Name[pt_BR]=Interface de configuração de contas do Pintxo
Name[ro]=Interfață de configurare a conturilor Pintxo
Name[ru]=Интерфейс для настройки учётной записи Pintxo
Name[sk]=Používateľské rozhranie konfigurácie účtu Pintxo
Name[sl]=Uporabniški vmesnik za nastavitev računov Pintxo
Name[sr]=Корисничко сучеље за подешавање налога под Пинтхом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Пинтхом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Pintxom
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Pintxom
Name[sv]=Användargränssnitt för inställning av Pintxo-konton
Name[tr]=Pintxo Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштовування облікового запису Pintxo
Name[x-test]=xxPintxo Account Configuration User Interfacexx
Name[zh_CN]=Pintxo 账户用户配置界面
Name[zh_TW]=Pintxo 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_pintxo
X-KDE-PluginInfo-Author=Anant Kamath
X-KDE-PluginInfo-Email=kamathanant@gmail.com
X-KDE-PluginInfo-Name=pintxo
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm-22.04.2.tar.xz: ktp-accounts-kcm-22.04.2/plugins/pintxo/ktpaccountskcm_plugin_pintxo.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Pintxo connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Pinxto menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Pintxo.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalisat per a comptes que utilisen el gestor de connexions Pintxo.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Pintxo.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Pintxo.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Pintxo-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Pintxo.
Comment[en_GB]=Custom account configuration user interface for accounts using the Pintxo connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Pintxo.
Comment[et]=Pintxo ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «Pintxo» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Pintxo-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur de configuration de comptes pour les comptes employant le gestionnaire de connexion « Pintxo ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Pintxo.
Comment[hu]=Egyedi beállítófelület a Pintxo kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Pintxo
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Pintxo.
Comment[kk]=Pintxo байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[ko]=Pintxo 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Pintxo ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Pintxo tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Pintxo“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Pintxo verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med Pintxo tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Pintxo.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Pintxo.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Pintxo.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Pintxo.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Pintxo.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Pintxo.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Pintxo.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Пинтхо.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Пинтхо.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Pintxo.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Pintxo.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Pintxo.
Comment[tr]=Pintxo bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікових записів, для роботи яких використовуються засоби керування з’єднанням Pintxo.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Pintxo connection manager.xx
Comment[zh_CN]=通过 Pintxo 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Pintxo 連線管理員的帳號自訂帳號設定使用者介面。
Icon=phone
Name=Pintxo Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Pinxto
Name[ca]=Interfície d'usuari de configuració del compte de Pintxo
Name[ca@valencia]=Interfície d'usuari de configuració del compte de Pintxo
Name[cs]=Uživatelské rozhraní nastavení účtu Pintxo
Name[da]=Brugerflade til Pintxo kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Pintxo-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη Pintxo
Name[en_GB]=Pintxo Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Pintxo
Name[et]=Pintxo konto seadistamise kasutajaliides
Name[eu]=«Pintxo» kontuak konfiguratzeko erabiltzaile interfazea
Name[fi]=Pintxo-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Pintxo ».
Name[gl]=Interface de usuario para a configuración de contas de Pintxo
Name[hu]=Pintxo azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Pintxo
Name[it]=Interfaccia utente di configurazione account Pintxo
Name[kk]=Pintxo тіркелгі пайдаланушы интерфейсін баптау
Name[ko]=Pintxo 계정 설정 사용자 인터페이스
Name[lt]=Pintxo paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Pintxo-konto
Name[nds]=Pintxo-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Pintxo accountconfiguratie
Name[nn]=Brukarflate for å setja opp Pintxo-konto
Name[pl]=Nakładka graficzna do ustawiania konta Pintxo
Name[pt]=Interface de Configuração de Contas do Pintxo
Name[pt_BR]=Interface de configuração de contas do Pintxo
Name[ro]=Interfață de configurare a conturilor Pintxo
Name[ru]=Интерфейс для настройки учётной записи Pintxo
Name[sk]=Používateľské rozhranie konfigurácie účtu Pintxo
Name[sl]=Uporabniški vmesnik za nastavitev računov Pintxo
Name[sr]=Корисничко сучеље за подешавање налога под Пинтхом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Пинтхом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Pintxom
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Pintxom
Name[sv]=Användargränssnitt för inställning av Pintxo-konton
Name[tr]=Pintxo Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштовування облікового запису Pintxo
Name[x-test]=xxPintxo Account Configuration User Interfacexx
Name[zh_CN]=Pintxo 账户用户配置界面
Name[zh_TW]=Pintxo 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_pintxo
X-KDE-PluginInfo-Author=Anant Kamath
X-KDE-PluginInfo-Email=kamathanant@gmail.com
X-KDE-PluginInfo-Name=pintxo
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
